@@ -1,31 +1,28 @@
+#define Py_LIMITED_API 0x03060000
 #define PY_SSIZE_T_CLEAN
-#include <Python.h>
+#include "Python.h"
 #include "pyobjc-api.h"
 
-#import <Foundation/Foundation.h>
 #import <CryptoTokenKit/CryptoTokenKit.h>
+#import <Foundation/Foundation.h>
 
 /* We include the source code here instead of
  * using the linker due to limitations in pyobjc-api.h
  */
 #include "_CryptoTokenKit_protocols.m"
 
-
 static PyMethodDef mod_methods[] = {
-    { 0, 0, 0, 0 } /* sentinel */
+    {0, 0, 0, 0} /* sentinel */
 };
 
-
 /* Python glue */
 PyObjC_MODULE_INIT(_CryptoTokenKit)
 {
     PyObject* m;
-    m = PyObjC_MODULE_CREATE(_CryptoTokenKit)
-    if (!m) {
-        PyObjC_INITERROR();
-    }
+    m = PyObjC_MODULE_CREATE(_CryptoTokenKit) if (!m) { PyObjC_INITERROR(); }
 
-    if (PyObjC_ImportAPI(m) == -1) PyObjC_INITERROR();
+    if (PyObjC_ImportAPI(m) == -1)
+        PyObjC_INITERROR();
 
     PyObjC_INITDONE();
 }
